%% run_sensorODE.m
% The "run_sensorODE" script is the top-level code demonstrating how one 
% might simulate the "sensorODE" function. You may edit the following 
% script however you see fit except for the following command:
%
% %% Solve "sensorODE"
% [output,outputTime,input,inputTime] = sensorODE_solver(@sensorODE,...
%     sensorInput,chatter,stochasticity,maxInputAmpl,initCond);
%
% NOTES:
% This script calls the "sensorODE_solver" function. Please do not 
% make any changes to the "sensorODE_solver" code.
%
% NECESSARY FILES (they must all be in the same directory):
% - sensorODE.m
% - sensorODE_solver.m
%
% LAST MODIFIED:
% October 2012 by Allison Claas
%
%--------------------------------------------------------------------------

%% Clear Workspace
clear; clc;

%% Define Inputs 1 & 2
% The following matrix must be M x 2, where input1 is defined in the left 
% column and input2 in the right column. (The number of rows maybe
% modified).
sensorInput = [...
                  ];
           
%% Define Initial State Conditions
% The following vector must be Sn x 1, where Sn reflects the number of states
% in your system.
initCond = ...;
           
%% Set Noise Flags
chatter       = false;
stochasticity = false;
maxInputAmpl  = 10;

%% Solve "sensorODE"
[output,outputTime,input,inputTime] = sensorODE_solver(@sensorODE,...
    sensorInput,chatter,stochasticity,maxInputAmpl,initCond);

%% Plot Results
% Simulate the sensor's response to the given (noise-free) input combinations. In your report, include the following plots:
% One figure that consists of 2 subplots with the following dynamic outputs:
% 1.	The first subplot should depict all state dynamics as a function of time. (How do your different species vary with time?)
% 2.	The second subplot should depict fluorescent output as a function of time. (Think about what you are measuring for fluorescence. Is it a certain species, transcription, etc.?)
% 
% Generate the subplot described above for the following conditions:
% 1.	Low Glucose (0.02 g/L)
% 2.	High Glucose (2 g/L)
% 3.	Low Contaminol (10 nM)
% 4.	High Contaminol (70 nM)
% 
% Note that your two systems can be completely independent such that you only need consider certain species for each condition above. If your two systems are dependent on each other, you must consider combinations of the above (i.e. low glucose and low contaminol, low glucose and high contaminol etc.).
% Finally, include a separate figure that is an equilibrium plot that depicts how the fluorescence changes with glucose or contaminol concentration for your two different systems. These should look something like the sample plots provided in the project description above. 
% 
% For all plots, clearly label titles, axes (with units!), and legends. 
% 
